@@ -184,9 +184,9 @@ get_summary.reg_fit_mediation <- function(object, boot = NULL, ...) {
     # extract coefficients
     if (p_m == 1L) coef_mx <- coef(object$fit_mx)
     else coef_mx <- unlist(unname(lapply(object$fit_mx, coef)))
-    c_prime <- object$c_prime
-    names(c_prime) <- object$x
-    coefficients <- c(coef_mx, coef(object$fit_ymx), c_prime)
+    total <- object$total
+    names(total) <- object$x
+    coefficients <- c(coef_mx, coef(object$fit_ymx), total)
     # compute standard errors and z-statistics from bootstrap replicates
     remove <- if(p_m == 1L) 1L else seq_len(1L + p_m)
     means <- colMeans(boot$t[, -remove], na.rm = TRUE)
@@ -245,24 +245,24 @@ get_summary.reg_fit_mediation <- function(object, boot = NULL, ...) {
     summary_ymx$coefficients <- coefficients[keep, , drop = FALSE]
   }
   ## extract direct effect of x on y
-  c <- summary_ymx$coefficients[2L + p_m, , drop = FALSE]
+  direct <- summary_ymx$coefficients[2L + p_m, , drop = FALSE]
   # summary of total effect of x on y
   if (have_boot) {
-    keep <- index_list$c_prime
-    c_prime <- coefficients[keep, , drop = FALSE]
+    keep <- index_list$total
+    total <- coefficients[keep, , drop = FALSE]
   } else if (robust) {
     # standard errors and t-test not available
-    c_prime <- matrix(c(object$c_prime, rep.int(NA_real_, 3L)), nrow = 1L)
-    dimnames(c_prime) <- dimnames(c)
+    total <- matrix(c(object$total, rep.int(NA_real_, 3L)), nrow = 1L)
+    dimnames(total) <- dimnames(direct)
   } else {
     # compute summary of y ~ x + covariates and extract summary of total effect
     summary_yx <- get_summary(object$fit_yx)
-    c_prime <- coef(summary_yx)[2L, , drop = FALSE]
+    total <- coef(summary_yx)[2L, , drop = FALSE]
   }
   # return results
-  result <- list(fit_mx = summary_mx, fit_ymx = summary_ymx, c_prime = c_prime,
-                 c = c, x = x, y = y, m = m, covariates = covariates, n = n,
-                 robust = robust, median = median)
+  result <- list(fit_mx = summary_mx, fit_ymx = summary_ymx, total = total,
+                 direct = direct, x = x, y = y, m = m, covariates = covariates,
+                 n = n, robust = robust, median = median)
   class(result) <- c("summary_reg_fit_mediation", "summary_fit_mediation")
   result
 }
@@ -275,9 +275,9 @@ get_summary.cov_fit_mediation <- function(object, boot = NULL, ...) {
   # extract coefficients
   a <- object$a
   b <- object$b
-  c <- object$c
-  c_prime <- object$c_prime
-  coefficients <- c(a, b, c, c_prime)
+  direct <- object$direct
+  total <- object$total
+  coefficients <- c(a, b, direct, total)
   # extract covariance matrix
   S <- object$cov$cov[c(x, m, y), c(x, m, y)]
   # extract number of observations
@@ -294,9 +294,9 @@ get_summary.cov_fit_mediation <- function(object, boot = NULL, ...) {
     # apply the delta method to obtain the inverse of the Fisher information
     # matrix for the coefficients in the mediation model, see Zu & Yuan (2010)
     s_epsilon_mx <- S[m,m] - a^2 * S[x,x]
-    h_dot <- matrix(c(-a/S[x,x], a*c/S[x,x], -a^2*c/s_epsilon_mx-c/S[x,x], 1, a^2, c^2,
-                     1/S[x,x], (a*b-c)/s_epsilon_mx, -b/S[x,x]-a*(a*b-c)/s_epsilon_mx, 0, -2*a, 2*b*c,
-                     0, -a/s_epsilon_mx, a^2/s_epsilon_mx+1/S[x,x], 0, 0, -2*c,
+    h_dot <- matrix(c(-a/S[x,x], a*direct/S[x,x], -a^2*direct/s_epsilon_mx-direct/S[x,x], 1, a^2, direct^2,
+                     1/S[x,x], (a*b-direct)/s_epsilon_mx, -b/S[x,x]-a*(a*b-direct)/s_epsilon_mx, 0, -2*a, 2*b*direct,
+                     0, -a/s_epsilon_mx, a^2/s_epsilon_mx+1/S[x,x], 0, 0, -2*direct,
                      0, -b/s_epsilon_mx, a*b/s_epsilon_mx, 0, 1, b^2,
                      0, 1/s_epsilon_mx, -a/s_epsilon_mx, 0, 0, -2*b,
                      0, 0, 0, 0, 0, 1),
@@ -304,7 +304,7 @@ get_summary.cov_fit_mediation <- function(object, boot = NULL, ...) {
     Omega_Theta <- h_dot %*% Omega_Sigma %*% t(h_dot)
     # total effect
     Omega_Sigma_yx <- Omega_Sigma[c(1, 3, 6), c(1, 3, 6)]
-    h_dot_yx <- matrix(c(-c_prime/S[x,x], 1, 0, 1/S[x,x], 0, -1, 0, 0, 1),
+    h_dot_yx <- matrix(c(-total/S[x,x], 1, 0, 1/S[x,x], 0, -1, 0, 0, 1),
                      nrow=3, ncol=3)
     Omega_Theta_yx <- h_dot_yx %*% Omega_Sigma_yx %*% t(h_dot_yx)
     # compute standard errors and z-statistics
@@ -325,13 +325,13 @@ get_summary.cov_fit_mediation <- function(object, boot = NULL, ...) {
   coefficients <- cbind(coefficients, means, se, z, p_value)
   dimnames(coefficients) <- list(c(x, m, x, x), tn)
   # # residual standard error as list (for compatibility with regression method)
-  # s_epsilon_ymx <- S[y,y] - b^2*S[m,m] - c^2*S[x,x] - 2*b*c*S[m,x]
+  # s_epsilon_ymx <- S[y,y] - b^2*S[m,m] - direct^2*S[x,x] - 2*b*direct*S[m,x]
   # s <- list(value=s_epsilon_ymx)
   # return results
   result <- list(a = coefficients[1, , drop = FALSE],
                  b = coefficients[2, , drop = FALSE],
-                 c_prime = coefficients[4, , drop = FALSE],
-                 c = coefficients[3, , drop = FALSE],
+                 total = coefficients[4, , drop = FALSE],
+                 direct = coefficients[3, , drop = FALSE],
                  x = x, y = y, m = m, n = n, robust = object$robust)
   class(result) <- c("summary_cov_fit_mediation", "summary_fit_mediation")
   result
