@@ -37,7 +37,7 @@ dot <- fortify(boot, method = "dot")
 density <- fortify(boot, method = "density")
 
 ## stuff needed to check correctness
-coef_names <- c("a", "b", "c", "c'", "ab")
+coef_names <- c("a", "b", "Direct", "Total", "ab")
 
 
 ## run tests
@@ -112,15 +112,15 @@ test_that("coef() method returns correct values of coefficients", {
   # bootstrapped effects
   expect_equivalent(coef(boot, parm = "a", type = "boot"), mean(boot$reps$t[, 3]))
   expect_equivalent(coef(boot, parm = "b", type = "boot"), mean(boot$reps$t[, 5]))
-  expect_equivalent(coef(boot, parm = "c", type = "boot"), mean(boot$reps$t[, 6]))
-  expect_equivalent(coef(boot, parm = "c'", type = "boot"), mean(boot$reps$t[, 7]))
+  expect_equivalent(coef(boot, parm = "Direct", type = "boot"), mean(boot$reps$t[, 6]))
+  expect_equivalent(coef(boot, parm = "Total", type = "boot"), mean(boot$reps$t[, 7]))
   expect_equivalent(coef(boot, parm = "ab", type = "boot"), boot$ab)
 
   # effects computed on original sample
   expect_equivalent(coef(boot, parm = "a", type = "data"), boot$fit$a)
   expect_equivalent(coef(boot, parm = "b", type = "data"), boot$fit$b)
-  expect_equivalent(coef(boot, parm = "c", type = "data"), boot$fit$c)
-  expect_equivalent(coef(boot, parm = "c'", type = "data"), boot$fit$c_prime)
+  expect_equivalent(coef(boot, parm = "Direct", type = "data"), boot$fit$direct)
+  expect_equivalent(coef(boot, parm = "Total", type = "data"), boot$fit$total)
   expect_equivalent(coef(boot, parm = "ab", type = "data"), boot$fit$a * boot$fit$b)
 
 })
@@ -210,20 +210,20 @@ test_that("effect summaries have correct names", {
   expect_identical(dim(summary_theory$summary$b), c(1L, 4L))
   expect_identical(rownames(summary_theory$summary$b), "M1")
   expect_identical(colnames(summary_theory$summary$b)[1], "Estimate")
-  # c path
-  expect_identical(dim(summary_boot$summary$c), c(1L, 5L))
-  expect_identical(rownames(summary_boot$summary$c), "X")
-  expect_identical(colnames(summary_boot$summary$c)[1:2], c("Data", "Boot"))
-  expect_identical(dim(summary_theory$summary$c), c(1L, 4L))
-  expect_identical(rownames(summary_theory$summary$c), "X")
-  expect_identical(colnames(summary_theory$summary$c)[1], "Estimate")
-  # c' path
-  expect_identical(dim(summary_boot$summary$c_prime), c(1L, 5L))
-  expect_identical(rownames(summary_boot$summary$c_prime), "X")
-  expect_identical(colnames(summary_boot$summary$c_prime)[1:2], c("Data", "Boot"))
-  expect_identical(dim(summary_theory$summary$c_prime), c(1L, 4L))
-  expect_identical(rownames(summary_theory$summary$c_prime), "X")
-  expect_identical(colnames(summary_theory$summary$c_prime)[1], "Estimate")
+  # direct effect
+  expect_identical(dim(summary_boot$summary$direct), c(1L, 5L))
+  expect_identical(rownames(summary_boot$summary$direct), "X")
+  expect_identical(colnames(summary_boot$summary$direct)[1:2], c("Data", "Boot"))
+  expect_identical(dim(summary_theory$summary$direct), c(1L, 4L))
+  expect_identical(rownames(summary_theory$summary$direct), "X")
+  expect_identical(colnames(summary_theory$summary$direct)[1], "Estimate")
+  # total effect
+  expect_identical(dim(summary_boot$summary$total), c(1L, 5L))
+  expect_identical(rownames(summary_boot$summary$total), "X")
+  expect_identical(colnames(summary_boot$summary$total)[1:2], c("Data", "Boot"))
+  expect_identical(dim(summary_theory$summary$total), c(1L, 4L))
+  expect_identical(rownames(summary_theory$summary$total), "X")
+  expect_identical(colnames(summary_theory$summary$total)[1], "Estimate")
   # no model fits
   expect_null(summary_boot$summary$fit_mx)
   expect_null(summary_boot$summary$fit_ymx)
@@ -237,18 +237,18 @@ test_that("effect summaries contain correct coefficient values", {
   # effects computed on original sample
   expect_identical(summary_boot$summary$a["X", "Data"], boot$fit$a)
   expect_identical(summary_boot$summary$b["M1", "Data"], boot$fit$b)
-  expect_identical(summary_boot$summary$c["X", "Data"], boot$fit$c)
-  expect_identical(summary_boot$summary$c_prime["X", "Data"], boot$fit$c_prime)
+  expect_identical(summary_boot$summary$direct["X", "Data"], boot$fit$direct)
+  expect_identical(summary_boot$summary$total["X", "Data"], boot$fit$total)
   expect_identical(summary_theory$summary$a["X", "Estimate"], boot$fit$a)
   expect_identical(summary_theory$summary$b["M1", "Estimate"], boot$fit$b)
-  expect_identical(summary_theory$summary$c["X", "Estimate"], boot$fit$c)
-  expect_identical(summary_theory$summary$c_prime["X", "Estimate"], boot$fit$c_prime)
+  expect_identical(summary_theory$summary$direct["X", "Estimate"], boot$fit$direct)
+  expect_identical(summary_theory$summary$total["X", "Estimate"], boot$fit$total)
 
   # bootstrapped effects
   expect_equal(summary_boot$summary$a["X", "Boot"], mean(boot$reps$t[, 3]))
   expect_equal(summary_boot$summary$b["M1", "Boot"], mean(boot$reps$t[, 5]))
-  expect_equal(summary_boot$summary$c["X", "Boot"], mean(boot$reps$t[, 6]))
-  expect_equal(summary_boot$summary$c_prime["X", "Boot"], mean(boot$reps$t[, 7]))
+  expect_equal(summary_boot$summary$direct["X", "Boot"], mean(boot$reps$t[, 6]))
+  expect_equal(summary_boot$summary$total["X", "Boot"], mean(boot$reps$t[, 7]))
 
 })
 
@@ -262,7 +262,7 @@ test_that("data returned by fortify() has correct structure", {
   column_names <- c("Effect", "Point", "Lower", "Upper")
   expect_named(dot, column_names)
   # check that direct effect and indirect effect are plotted by default
-  effect_names <- c("c", "ab")
+  effect_names <- c("Direct", "ab")
   expect_identical(dot$Effect, factor(effect_names, levels = effect_names))
 
   ## density plot
