@@ -34,7 +34,7 @@ dot <- fortify(boot, method = "dot")
 density <- fortify(boot, method = "density")
 
 ## stuff needed to check correctness
-coef_names <- c("a", "b", "c", "c'", "ab")
+coef_names <- c("a", "b", "Direct", "Total", "ab")
 mx_names <- c("(Intercept)", "X")
 ymx_names <- c("(Intercept)", "M", "X")
 
@@ -112,15 +112,15 @@ test_that("coef() method returns correct values of coefficients", {
   # bootstrapped effects
   expect_equivalent(coef(boot, parm = "a", type = "boot"), mean(boot$reps$t[, 3]))
   expect_equivalent(coef(boot, parm = "b", type = "boot"), mean(boot$reps$t[, 5]))
-  expect_equivalent(coef(boot, parm = "c", type = "boot"), mean(boot$reps$t[, 6]))
-  expect_equivalent(coef(boot, parm = "c'", type = "boot"), mean(boot$reps$t[, 7]))
+  expect_equivalent(coef(boot, parm = "Direct", type = "boot"), mean(boot$reps$t[, 6]))
+  expect_equivalent(coef(boot, parm = "Total", type = "boot"), mean(boot$reps$t[, 7]))
   expect_equivalent(coef(boot, parm = "ab", type = "boot"), boot$ab)
 
   # effects computed on original sample
   expect_equivalent(coef(boot, parm = "a", type = "data"), boot$fit$a)
   expect_equivalent(coef(boot, parm = "b", type = "data"), boot$fit$b)
-  expect_equivalent(coef(boot, parm = "c", type = "data"), boot$fit$c)
-  expect_equivalent(coef(boot, parm = "c'", type = "data"), boot$fit$c_prime)
+  expect_equivalent(coef(boot, parm = "Direct", type = "data"), boot$fit$direct)
+  expect_equivalent(coef(boot, parm = "Total", type = "data"), boot$fit$total)
   expect_equivalent(coef(boot, parm = "ab", type = "data"), boot$fit$a * boot$fit$b)
 
 })
@@ -228,20 +228,20 @@ test_that("effect summaries have correct names", {
   expect_identical(dim(summary_theory$summary$fit_ymx$coefficient), c(3L, 4L))
   expect_identical(rownames(summary_theory$summary$fit_ymx$coefficient), ymx_names)
   expect_identical(colnames(summary_theory$summary$fit_ymx$coefficient)[1], "Estimate")
-  # c path
-  expect_identical(dim(summary_boot$summary$c), c(1L, 5L))
-  expect_identical(rownames(summary_boot$summary$c), "X")
-  expect_identical(colnames(summary_boot$summary$c)[1:2], c("Data", "Boot"))
-  expect_identical(dim(summary_theory$summary$c), c(1L, 4L))
-  expect_identical(rownames(summary_theory$summary$c), "X")
-  expect_identical(colnames(summary_theory$summary$c)[1], "Estimate")
-  # c' path
-  expect_identical(dim(summary_boot$summary$c_prime), c(1L, 5L))
-  expect_identical(rownames(summary_boot$summary$c_prime), "X")
-  expect_identical(colnames(summary_boot$summary$c_prime)[1:2], c("Data", "Boot"))
-  expect_identical(dim(summary_theory$summary$c_prime), c(1L, 4L))
-  expect_identical(rownames(summary_theory$summary$c_prime), "X")
-  expect_identical(colnames(summary_theory$summary$c_prime)[1], "Estimate")
+  # direct effect
+  expect_identical(dim(summary_boot$summary$direct), c(1L, 5L))
+  expect_identical(rownames(summary_boot$summary$direct), "X")
+  expect_identical(colnames(summary_boot$summary$direct)[1:2], c("Data", "Boot"))
+  expect_identical(dim(summary_theory$summary$direct), c(1L, 4L))
+  expect_identical(rownames(summary_theory$summary$direct), "X")
+  expect_identical(colnames(summary_theory$summary$direct)[1], "Estimate")
+  # total effect
+  expect_identical(dim(summary_boot$summary$total), c(1L, 5L))
+  expect_identical(rownames(summary_boot$summary$total), "X")
+  expect_identical(colnames(summary_boot$summary$total)[1:2], c("Data", "Boot"))
+  expect_identical(dim(summary_theory$summary$total), c(1L, 4L))
+  expect_identical(rownames(summary_theory$summary$total), "X")
+  expect_identical(colnames(summary_theory$summary$total)[1], "Estimate")
 
 })
 
@@ -250,18 +250,18 @@ test_that("effect summaries contain correct coefficient values", {
   # effects computed on original sample
   expect_equivalent(summary_boot$summary$fit_mx$coefficients[2, "Data"], boot$fit$a)
   expect_identical(summary_boot$summary$fit_ymx$coefficients[2, "Data"], boot$fit$b)
-  expect_identical(summary_boot$summary$c["X", "Data"], boot$fit$c)
-  expect_identical(summary_boot$summary$c_prime["X", "Data"], boot$fit$c_prime)
+  expect_identical(summary_boot$summary$direct["X", "Data"], boot$fit$direct)
+  expect_identical(summary_boot$summary$total["X", "Data"], boot$fit$total)
   expect_equivalent(summary_theory$summary$fit_mx$coefficients[2, "Estimate"], boot$fit$a)
   expect_identical(summary_theory$summary$fit_ymx$coefficients[2, "Estimate"], boot$fit$b)
-  expect_identical(summary_theory$summary$c["X", "Estimate"], boot$fit$c)
-  expect_identical(summary_theory$summary$c_prime["X", "Estimate"], boot$fit$c_prime)
+  expect_identical(summary_theory$summary$direct["X", "Estimate"], boot$fit$direct)
+  expect_identical(summary_theory$summary$total["X", "Estimate"], boot$fit$total)
 
   # bootstrapped effects
   expect_equivalent(summary_boot$summary$fit_mx$coefficients[2, "Boot"], mean(boot$reps$t[, 3]))
   expect_equivalent(summary_boot$summary$fit_ymx$coefficients[2, "Boot"], mean(boot$reps$t[, 5]))
-  expect_equal(summary_boot$summary$c["X", "Boot"], mean(boot$reps$t[, 6]))
-  expect_equal(summary_boot$summary$c_prime["X", "Boot"], mean(boot$reps$t[, 7]))
+  expect_equal(summary_boot$summary$direct["X", "Boot"], mean(boot$reps$t[, 6]))
+  expect_equal(summary_boot$summary$total["X", "Boot"], mean(boot$reps$t[, 7]))
 
 })
 
@@ -275,7 +275,7 @@ test_that("data returned by fortify() has correct structure", {
   column_names <- c("Effect", "Point", "Lower", "Upper")
   expect_named(dot, column_names)
   # check that direct effect and indirect effect are plotted by default
-  effect_names <- c("c", "ab")
+  effect_names <- c("Direct", "ab")
   expect_identical(dot$Effect, factor(effect_names, levels = effect_names))
 
   ## density plot
